@@ -17,8 +17,8 @@ class SageExpression : public Cantor::Expression
     void evaluate() override;
     void interrupt() override;
 
-    void parseOutput(const QString&);
-    void parseError(const QString&);
+    void parseOutput(const QString&) override;
+    void parseError(const QString&) override;
 
     void addFileResult(const QString&);
 
